@@ -333,7 +333,7 @@ class CRM_Admin_Form_PaymentProcessor extends CRM_Admin_Form {
     $cards = json_decode(CRM_Core_DAO::getFieldValue('CRM_Financial_DAO_PaymentProcessor',
           $this->_id,
           'accepted_credit_cards'
-        ), TRUE);
+         ) ?? '', TRUE);
     $acceptedCards = [];
     if (!empty($cards)) {
       foreach ($cards as $card => $val) {
@@ -467,11 +467,8 @@ class CRM_Admin_Form_PaymentProcessor extends CRM_Admin_Form {
       $this->set('pp', $this->_paymentProcessorType);
     }
     else {
-      $paymentProcessorTypes = CRM_Core_PseudoConstant::get('CRM_Financial_DAO_PaymentProcessor', 'payment_processor_type_id', [
-        'labelColumn' => 'name',
-        'flip' => 1,
-      ]);
-      $this->_paymentProcessorType = CRM_Utils_Request::retrieve('pp', 'String', $this, FALSE, $paymentProcessorTypes['PayPal']);
+      $payPal = CRM_Core_PseudoConstant::getKey('CRM_Financial_DAO_PaymentProcessor', 'payment_processor_type_id', 'PayPal');
+      $this->_paymentProcessorType = CRM_Utils_Request::retrieve('pp', 'String', $this, FALSE, $payPal);
     }
   }
 
