@@ -18,8 +18,7 @@
 /**
  * This class contains function for UFField.
  */
-class CRM_Core_BAO_UFField extends CRM_Core_DAO_UFField {
-
+class CRM_Core_BAO_UFField extends CRM_Core_DAO_UFField implements \Civi\Core\HookInterface {
   /**
    * Batch entry fields.
    * @var array
@@ -56,11 +55,6 @@ class CRM_Core_BAO_UFField extends CRM_Core_DAO_UFField {
       }
     }
 
-    // Validate field_name
-    if (strpos($params['field_name'], 'formatting') !== 0 && !CRM_Core_BAO_UFField::isValidFieldName($params['field_name'])) {
-      throw new CRM_Core_Exception('The field_name is not valid');
-    }
-
     // Supply default label if not set
     if (empty($id) && !isset($params['label'])) {
       $params['label'] = self::getAvailableFieldTitles()[$params['field_name']];
@@ -281,9 +275,10 @@ class CRM_Core_BAO_UFField extends CRM_Core_DAO_UFField {
    * Delete profile field given a custom field.
    *
    * @param int $customFieldId
-   *   ID of the custom field to be deleted.
+   * @deprecated
    */
   public static function delUFField($customFieldId) {
+    CRM_Core_Error::deprecatedFunctionWarning('Api');
     //find the profile id given custom field id
     $ufField = new CRM_Core_DAO_UFField();
     $ufField->field_name = "custom_" . $customFieldId;
@@ -1135,4 +1130,17 @@ SELECT  id
     return self::$_memberBatchEntryFields;
   }
 
+  /**
+   * Callback for hook_civicrm_pre().
+   * @param \Civi\Core\Event\PreEvent $event
+   * @throws CRM_Core_Exception
+   */
+  public static function on_hook_civicrm_pre(\Civi\Core\Event\PreEvent $event) {
+    if ($event->action === 'delete' && $event->entity === 'CustomField') {
+      \Civi\Api4\UFField::delete(FALSE)
+        ->addWhere('field_name', '=', 'custom_' . $event->id)
+        ->execute();
+    }
+  }
+
 }
