@@ -21,6 +21,28 @@ use Civi\Token\TokenProcessor;
  */
 class CRM_Core_SelectValues {
 
+  /**
+   * The possible attributes of each item in an option list
+   *
+   * APIv4 refers to these as "suffixes".
+   *
+   * @return array
+   */
+  public static function optionAttributes():array {
+    static $attributes;
+    $attributes ??= [
+      'label' => ts('Label'),
+      'name' => ts('Internal Name'),
+      'description' => ts('Description'),
+      'abbr' => ts('Abbreviation'),
+      'icon' => ts('Icon'),
+      'color' => ts('Color'),
+      'grouping' => ts('Grouping'),
+      'url' => ts('Url'),
+    ];
+    return $attributes;
+  }
+
   /**
    * Yes/No options
    *
@@ -58,7 +80,7 @@ class CRM_Core_SelectValues {
       'do_not_mail' => ts('Do not mail'),
       'do_not_sms' => ts('Do not sms'),
       'do_not_trade' => ts('Do not trade'),
-      'is_opt_out' => ts('No bulk emails (User Opt Out)'),
+      'is_opt_out' => ts('No Bulk Emails (User Opt Out)'),
     ];
   }
 
@@ -541,24 +563,6 @@ class CRM_Core_SelectValues {
     return $tokenProcessor->listTokens();
   }
 
-  /**
-   * Different type of Pledge Tokens.
-   *
-   * @return array
-   */
-  public static function pledgeTokens() {
-    return [
-      '{pledge.pledge_balance}' => ts('Pledge Balance'),
-      '{pledge.id}' => ts('Pledge ID'),
-      '{pledge.pledge_financial_type}' => ts('Pledge Financial Type'),
-      '{pledge.pledge_amount}' => ts('Total pledge amount'),
-      '{pledge.create_date}' => ts('Pledge Start Date'),
-      '{pledge.pledge_next_pay_date}' => ts('Upcoming pledge payment date'),
-      '{pledge.pledge_next_pay_amount}' => ts('Upcoming pledge payment amount'),
-      '{pledge.pledge_total_paid}' => ts('Total pledge payments'),
-    ];
-  }
-
   /**
    * Different type of Activity Tokens.
    *
@@ -792,6 +796,7 @@ class CRM_Core_SelectValues {
     return [
       'Admin' => ts('Admin'),
       'Email' => ts('Email'),
+      'Form' => ts('Form'),
       'Web' => ts('Web'),
       'API' => ts('API'),
     ];
@@ -1291,6 +1296,9 @@ class CRM_Core_SelectValues {
   /**
    * Columns from the option_value table which may or may not be used by each option_group.
    *
+   * This is a subset of the full list of optionAttributes
+   * @see self::optionAttributes()
+   *
    * Note: Value is not listed here as it is not optional.
    *
    * @return string[]
@@ -1302,6 +1310,7 @@ class CRM_Core_SelectValues {
       'description' => 'description',
       'icon' => 'icon',
       'color' => 'color',
+      'grouping' => 'grouping',
     ];
   }
 
@@ -1324,4 +1333,18 @@ class CRM_Core_SelectValues {
     return $options;
   }
 
+  /**
+   * @return array
+   *   Array(string $machineName => string $label).
+   */
+  public static function getPDFLoggingOptions() {
+    return [
+      'none' => ts('Do not record'),
+      'multiple' => ts('Multiple activities (one per contact)'),
+      'combined' => ts('One combined activity'),
+      'combined-attached' => ts('One combined activity plus one file attachment'),
+      // 'multiple-attached' <== not worth the work
+    ];
+  }
+
 }
