@@ -873,23 +873,13 @@ WHERE civicrm_pledge_payment.contribution_id = {$paymentContributionId}
   }
 
   /**
-   * Override buildOptions to hack out some statuses.
-   *
-   * @todo instead of using & hacking the shared optionGroup contribution_status use a separate one.
-   *
-   * @param string $fieldName
-   * @param string $context
-   * @param array $props
-   *
-   * @return array|bool
+   * Pseudoconstant condition_provider for status_id field.
+   * @see \Civi\Schema\EntityMetadataBase::getConditionFromProvider
    */
-  public static function buildOptions($fieldName, $context = NULL, $props = []) {
-    $result = parent::buildOptions($fieldName, $context, $props);
-    if ($fieldName == 'status_id') {
-      $result = CRM_Pledge_BAO_Pledge::buildOptions($fieldName, $context, $props);
-      $result = array_diff($result, ['Failed', 'In Progress']);
+  public static function alterStatus(string $fieldName, CRM_Utils_SQL_Select $conditions, $params) {
+    if ($fieldName == 'status_id' && !$params['include_disabled']) {
+      $conditions->where('name NOT IN (@status)', ['status' => ['Failed', 'In Progress']]);
     }
-    return $result;
   }
 
   /**
