@@ -642,6 +642,8 @@ class CRM_Utils_String {
       $config->set('Cache.DefinitionImpl', NULL);
       $config->set('HTML.DefinitionID', 'enduser-customize.html tutorial');
       $config->set('HTML.DefinitionRev', 1);
+      $config->set('HTML.MaxImgLength', NULL);
+      $config->set('CSS.MaxImgLength', NULL);
       $def = $config->maybeGetRawHTMLDefinition();
       if (!empty($def)) {
         $def->addElement('figcaption', 'Block', 'Flow', 'Common');
@@ -1112,4 +1114,21 @@ class CRM_Utils_String {
     return $tokens;
   }
 
+  public static function isQuotedString($value): bool {
+    return is_string($value) && strlen($value) > 1 && $value[0] === $value[-1] && in_array($value[0], ['"', "'"]);
+  }
+
+  public static function unquoteString(string $string): string {
+    // Strip the outer quotes if the string starts and ends with the same quote type
+    if (self::isQuotedString($string)) {
+      $string = substr($string, 1, -1);
+
+      // Replace escaped quotes with unescaped quotes, avoiding escaped backslashes
+      $string = preg_replace('/(?<!\\\\)\\\\\\"/', '"', $string);
+      $string = preg_replace('/(?<!\\\\)\\\\\\\'/', "'", $string);
+    }
+
+    return $string;
+  }
+
 }
